@@ -27,8 +27,7 @@
 //! // 3d mesh with depth of 0.5
 //! let mesh_3d: Mesh<Mesh3d> = glyph.to_3d_mesh(Quality::Medium, 0.5).unwrap();
 //! ```
-#![feature(test)]
-extern crate test;
+#![cfg_attr(feature = "unstable", feature(test))]
 
 use std::{ffi::CString, os::unix::prelude::OsStrExt, path::Path};
 
@@ -57,7 +56,6 @@ mod tests {
     use std::path::PathBuf;
 
     use super::*;
-    use test::Bencher;
 
     fn get_font_path() -> PathBuf {
         PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("fonts")
@@ -70,7 +68,7 @@ mod tests {
         }
     }
 
-    fn read_font(font_file: Option<&str>) -> Vec<u8> {
+    pub(crate) fn read_font(font_file: Option<&str>) -> Vec<u8> {
         std::fs::read(get_font(font_file)).unwrap()
     }
 
@@ -87,14 +85,13 @@ mod tests {
     #[test]
     fn test_get_glyph_from_char() {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-        let char = "A".chars().next().unwrap();
-        let _ = font.glyph_from_char(char).unwrap();
+        let _ = font.glyph_from_char('A').unwrap();
     }
 
     #[test]
     fn test_to_3d_mesh() {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-        let mut glyph = font.glyph_from_char("€".chars().next().unwrap()).unwrap();
+        let mut glyph = font.glyph_from_char('€').unwrap();
         let mesh = glyph.to_3d_mesh(Quality::Low, 0.5).unwrap();
 
         let mut sizes = Vec::new();
@@ -126,7 +123,7 @@ mod tests {
     #[test]
     fn test_to_2d_mesh() {
         let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-        let mut glyph = font.glyph_from_char("€".chars().next().unwrap()).unwrap();
+        let mut glyph = font.glyph_from_char('€').unwrap();
 
         let mut sizes = Vec::new();
         let mesh = glyph.to_2d_mesh(Quality::Low).unwrap();
@@ -150,10 +147,18 @@ mod tests {
 
         assert_eq!(sizes, &[41, 39, 92, 90, 194, 192]);
     }
+}
+
+#[cfg(all(feature = "unstable", test))]
+mod bench {
+    extern crate test;
+
+    use super::*;
+    use test::Bencher;
 
     #[bench]
     fn bench_open_font(b: &mut Bencher) {
-        let buffer = read_font(None);
+        let buffer = tests::read_font(None);
 
         b.iter(|| {
             let _ = TTFFile::from_buffer_vec(buffer.clone()).unwrap();
@@ -162,20 +167,17 @@ mod tests {
 
     #[bench]
     fn bench_get_glyph(b: &mut Bencher) {
-        let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-        let char = "€".chars().next().unwrap();
+        let mut font = TTFFile::from_buffer_vec(tests::read_font(None)).unwrap();
 
         b.iter(|| {
-            let _ = font.glyph_from_char(char).unwrap();
+            let _ = font.glyph_from_char('€').unwrap();
         });
     }
 
     #[bench]
     fn bench_glyph_to_3d_mesh_low_quality(b: &mut Bencher) {
-        let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-
-        let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_from_char(char).unwrap();
+        let mut font = TTFFile::from_buffer_vec(tests::read_font(None)).unwrap();
+        let mut glyph = font.glyph_from_char('€').unwrap();
 
         b.iter(|| {
             let _ = glyph.to_3d_mesh(Quality::Low, 0.1).unwrap();
@@ -184,10 +186,8 @@ mod tests {
 
     #[bench]
     fn bench_glyph_to_3d_mesh_high_quality(b: &mut Bencher) {
-        let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-
-        let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_from_char(char).unwrap();
+        let mut font = TTFFile::from_buffer_vec(tests::read_font(None)).unwrap();
+        let mut glyph = font.glyph_from_char('€').unwrap();
 
         b.iter(|| {
             let _ = glyph.to_3d_mesh(Quality::High, 0.1).unwrap();
@@ -196,10 +196,8 @@ mod tests {
 
     #[bench]
     fn bench_glyph_to_2d_mesh_low_quality(b: &mut Bencher) {
-        let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-
-        let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_from_char(char).unwrap();
+        let mut font = TTFFile::from_buffer_vec(tests::read_font(None)).unwrap();
+        let mut glyph = font.glyph_from_char('€').unwrap();
 
         b.iter(|| {
             let _ = glyph.to_2d_mesh(Quality::Low).unwrap();
@@ -208,10 +206,8 @@ mod tests {
 
     #[bench]
     fn bench_glyph_to_2d_mesh_high_quality(b: &mut Bencher) {
-        let mut font = TTFFile::from_buffer_vec(read_font(None)).unwrap();
-
-        let char = "€".chars().next().unwrap();
-        let mut glyph = font.glyph_from_char(char).unwrap();
+        let mut font = TTFFile::from_buffer_vec(tests::read_font(None)).unwrap();
+        let mut glyph = font.glyph_from_char('€').unwrap();
 
         b.iter(|| {
             let _ = glyph.to_2d_mesh(Quality::High).unwrap();
